@@ -633,10 +633,10 @@ psdrawpoint(GtkPlotPC *pc, gdouble x, gdouble y)
 {
   FILE *psout = GTK_PLOT_PS(pc)->psfile;
 
-#if 0
-  fprintf(psout, "n %g %g m %g %g l s\n", x, y, x, y);
-#endif
-  fprintf(psout, "%g %g 0.15 0 360 arc s\n", x, y);
+  fprintf(psout, "n\n");
+  fprintf(psout, "%g %g m\n", x, y);
+  fprintf(psout, "%g %g l\n", x, y);
+  fprintf(psout, "s\n");
 }
 
 static void
@@ -736,17 +736,16 @@ psoutputstring (GtkPlotPC *pc,
 		GtkPSFont *psfont,
 		GtkPSFont *latin_psfont,
 		gint height,
-		const GdkWChar *wstring,
+		const gchar *wstring,
 		const gchar *addstring)
 {
-  const GdkWChar *p;
-  GdkWChar wcs[2];
-  gint curcode = 0, code; /* 0..neither 1..latin 2..i18n */
+  const gchar *p;
+  gint curcode = 0;
   gchar begin[] = { 0, '(', '<' };
   gchar end[] = { 0, ')', '>' };
   GtkPSFont *fonts[3];
   FILE *out = GTK_PLOT_PS(pc)->psfile;
-  gchar *mbs, *c;
+  const gchar *c = NULL;
  
   fonts[0] = NULL;
   fonts[1] = latin_psfont;
@@ -755,6 +754,9 @@ psoutputstring (GtkPlotPC *pc,
   p = wstring;
   
   if (psfont->i18n_latinfamily) {
+/*    gint code; */ /* 0..neither 1..latin 2..i18n */
+/*
+    gchar wcs[2];
     while (*p) {
       code = (*p >= 0 && *p <= 0x7f) ? 1 : 2;
       if (curcode && curcode != code)
@@ -768,7 +770,7 @@ psoutputstring (GtkPlotPC *pc,
 
       wcs[0] = *p++;
       wcs[1] = 0;
-      c = mbs = gdk_wcstombs(wcs);
+      c = wcs;
       
       if (code == 2) {
 	while (*c)
@@ -778,25 +780,28 @@ psoutputstring (GtkPlotPC *pc,
 	  fputc('\\', out);
 	fputc(*c, out);
       }
-      
-      g_free(mbs);
     }
+*/
   } else {
-    c = mbs = gdk_wcstombs(wstring);
+    c = wstring;
     
-    while (*c) {
-      if (curcode == 0) {
-	pssetfont(pc, psfont, height);
-	fputc(begin[1], out);
-	curcode = 1;
-      }
+    pssetfont(pc, psfont, height);
+    fputc(begin[1], out);
+    curcode = 1;
 
+    while (*c) {
+      const gchar *aux2 = c;
       if (*c == '(' || *c == ')')
 	fputc('\\', out);
-      fputc(*c++, out);
+     
+      if(++aux2 != g_utf8_next_char(c)){
+        fprintf(out, ") show <%02x> show (", (unsigned char)(*++c));
+        c++;
+      } else {
+        fputc(*c, out);
+        c = g_utf8_next_char(c);
+      } 
     }
-
-    g_free(mbs);
   }
 
   if (curcode)
@@ -833,7 +838,8 @@ psdrawstring	(GtkPlotPC *pc,
   gint twidth, theight, tdescent, tascent;
   gint tx, ty, width, height; 
   gint i;
-  GdkWChar *curstr, *wtext, *lastchar = NULL, bkspchar[2], *aux, *xaux;
+  const gchar *aux, *xaux, *wtext, *lastchar = NULL;
+  gchar *curstr, bkspchar[3];
   gchar num[4];
 
   if (text == NULL || strlen(text) == 0) return;
@@ -911,7 +917,7 @@ psdrawstring	(GtkPlotPC *pc,
   c = text;
   while(c && *c != '\0' && *c != '\n') {
      if(*c == '\\'){
-         c++;
+         c = g_utf8_next_char(c);
          switch(*c){
            case '0': case '1': case '2': case '3':
            case '4': case '5': case '6': case '7': case '9':
@@ -923,7 +929,7 @@ psdrawstring	(GtkPlotPC *pc,
              break;
          }
      } else {
-         c++;
+         c = g_utf8_next_char(c);
      }
   }
 
@@ -966,17 +972,16 @@ psdrawstring	(GtkPlotPC *pc,
     return;
   }
 
-  i = strlen(text) + 2;
-  curstr = g_malloc0(sizeof(GdkWChar) * i);
-  aux = wtext = g_malloc0(sizeof(GdkWChar) * i);
-  gdk_mbstowcs(wtext, text, i - 1);
+  i = g_utf8_strlen(text, -1) + 2;
+  curstr = g_malloc0(sizeof(gchar) * i);
+  aux = wtext = text; 
 
   scale = font_height;
   curcnt = 0;
 
   while(aux && *aux != '\0' && *aux != '\n') {
      if(*aux == '\\'){
-         aux++;
+         aux = g_utf8_next_char(aux);
          switch(*aux){
            case '0': case '1': case '2': case '3':
            case '4': case '5': case '6': case '7': case '9':
@@ -985,7 +990,7 @@ psdrawstring	(GtkPlotPC *pc,
 				 curstr, "show");
                   curcnt = 0;
                   psfont = gtk_psfont_get_by_family((gchar *)g_list_nth_data(family, *aux-'0'), italic, bold);
-		  aux++;
+		  aux = g_utf8_next_char(aux);
                   break;
            case '8':case 'g':
                   curstr[curcnt] = 0;
@@ -993,7 +998,7 @@ psdrawstring	(GtkPlotPC *pc,
 				 curstr, "show");
                   curcnt = 0;
                   psfont = gtk_psfont_get_by_family("Symbol", italic, bold);
-                  aux++;
+                  aux = g_utf8_next_char(aux);
                   break;
            case 'B':
                   curstr[curcnt] = 0;
@@ -1004,7 +1009,7 @@ psdrawstring	(GtkPlotPC *pc,
                   psfont = gtk_psfont_get_by_family(psfont->family, italic, bold);
 		  if (psfont->i18n_latinfamily)
 		    latin_psfont = gtk_psfont_get_by_family(psfont->i18n_latinfamily, italic, bold);
-		  aux++;
+		  aux = g_utf8_next_char(aux);
                   break;
            case 'x':
                   xaux = aux + 1;
@@ -1015,7 +1020,7 @@ psdrawstring	(GtkPlotPC *pc,
 		      break;
                   }
                   if (i < 3){
-                     aux++;
+                     aux = g_utf8_next_char(aux);
                      break;
                   }
                   num[3] = '\0';
@@ -1040,7 +1045,7 @@ psdrawstring	(GtkPlotPC *pc,
                   psfont = gtk_psfont_get_by_family(psfont->family, italic, bold);
 		  if (psfont->i18n_latinfamily)
 		    latin_psfont = gtk_psfont_get_by_family(psfont->i18n_latinfamily, italic, bold);
-		  aux++;
+		  aux = g_utf8_next_char(aux);
                   break;
            case 's':case '_':
                   curstr[curcnt] = 0;
@@ -1050,7 +1055,7 @@ psdrawstring	(GtkPlotPC *pc,
                   scale = 0.6 * font_height;
 		  offset -= (gint)scale / 2;
                   fprintf(psout, "0 %d rmoveto\n", -((gint)scale / 2));
-                  aux++;
+                  aux = g_utf8_next_char(aux);
                   break;
            case 'S':case '^':
                   curstr[curcnt] = 0;
@@ -1060,7 +1065,7 @@ psdrawstring	(GtkPlotPC *pc,
                   scale = 0.6 * font_height;
 		  offset += 0.5*font_height;
                   fprintf(psout, "0 %d rmoveto\n", (gint)(0.5*font_height));
-                  aux++;
+                  aux = g_utf8_next_char(aux);
                   break;
            case 'N':
                   curstr[curcnt] = 0;
@@ -1077,17 +1082,23 @@ psdrawstring	(GtkPlotPC *pc,
                   scale = font_height;
                   fprintf(psout, "0 %d rmoveto\n", -offset);
                   offset = 0;
-                  aux++;
+                  aux = g_utf8_next_char(aux);
                   break;
            case 'b':
                   curstr[curcnt] = '\0';
                   psoutputstring(pc, psfont, latin_psfont, (gint)scale,
 				 curstr, "show");
                   curcnt = 0;
-		  bkspchar[1] = 0;
                   if (lastchar) {
+                      const gchar *aux2 = lastchar;
                       bkspchar[0] = *lastchar;
-                      lastchar--;
+                      lastchar = g_utf8_prev_char(lastchar);
+		      bkspchar[1] = 0;
+                      if(--aux2 != lastchar){
+                        bkspchar[1] = *lastchar;
+                        lastchar = g_utf8_prev_char(lastchar);
+		        bkspchar[2] = 0;
+                      }
                   } else {
                       bkspchar[0] = 'X';
                       lastchar = NULL;
@@ -1095,7 +1106,7 @@ psdrawstring	(GtkPlotPC *pc,
 		  psoutputstring(pc, psfont, latin_psfont, (gint)scale,
 				 bkspchar,
 				 "stringwidth pop 0 exch neg exch rmoveto");
-                  aux++;
+                  aux = g_utf8_next_char(aux);
                   break;
            case '-':
                   curstr[curcnt] = 0;
@@ -1106,7 +1117,7 @@ psdrawstring	(GtkPlotPC *pc,
                   if (scale < 6) {
                       scale = 6;
                   }
-                  aux++;
+                  aux = g_utf8_next_char(aux);
                   break;
            case '+':
                   curstr[curcnt] = 0;
@@ -1114,21 +1125,27 @@ psdrawstring	(GtkPlotPC *pc,
 				 curstr, "show");
                   curcnt = 0;
                   scale += 3;
-                  aux++;
+                  aux = g_utf8_next_char(aux);
                   break;
            default:
                   if(aux && *aux != '\0' && *aux != '\n'){
                     curstr[curcnt++] = *aux;
-                    aux++;
+                    aux = g_utf8_next_char(aux);
                   }
                   break;
          }
      } else {
        if(aux && *aux != '\0' && *aux != '\n'){
-                curstr[curcnt++] = *aux;
-		lastchar = aux;
-                aux++;
-
+                const gchar *aux2 = aux;
+                if(g_utf8_next_char(aux) != ++aux2){
+                  curstr[curcnt++] = *aux++;
+/*                  aux = g_utf8_next_char(aux); */
+                  curstr[curcnt++] = *aux++;
+                } else {
+                  curstr[curcnt++] = *aux;
+		  lastchar = aux;
+                  aux = g_utf8_next_char(aux);
+                }
        }
      }
   }
@@ -1138,8 +1155,6 @@ psdrawstring	(GtkPlotPC *pc,
   psgrestore(pc);  
   fprintf(psout, "n\n");  
 
-
-  g_free(wtext);
   g_free(curstr);
 }
 
@@ -1313,7 +1328,6 @@ psdrawpixmap  (GtkPlotPC *pc,
     fprintf(psout, "{ currentfile scanline readhexstring pop } false 3\n");
     fprintf(psout, "colorimage\n");
 
-
     for(y = 0; y < height; y++){
       for(x = 0; x < width; x++){
         GdkColor color;
