@@ -34,6 +34,7 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <unistd.h>
+
 #define GDK_PIXBUF_ENABLE_BACKEND
 #include <gdk-pixbuf/gdk-pixbuf-io.h>
 #include <gdk-pixbuf/gdk-pixbuf-animation.h>
@@ -41,22 +42,31 @@
 #include <gtk/gtkmain.h>
 #include <gdk/gdkkeysyms.h>
 
+#include "module.h"
+
+#ifdef HAVE_CAIRO
+#include <cairo.h>
+#ifdef CAIRO_HAS_SVG_SURFACE
+#   include <cairo-svg.h>
+#endif
+#ifdef CAIRO_HAS_PS_SURFACE
+#   include <cairo-ps.h>
+#endif
+#ifdef CAIRO_HAS_PDF_SURFACE
+#include <cairo-pdf.h>
+#endif
+#include <cairo-xlib.h>
+#endif
+
 #ifdef HAVE_GTKEXTRA
 #include "gtkextra/gtkextra.h"
 #endif
 
-#include "module.h"
 #include "slgtkicons.h"
 
-const unsigned char slgtk_major_ver	  = SLGTK_MAJOR_VERSION;
-const unsigned char slgtk_minor_ver	  = SLGTK_MINOR_VERSION;
-const unsigned char slgtk_micro_ver	  = SLGTK_MICRO_VERSION;
-const int	    slgtk_version	  = SLGTK_VERSION;
-const char	    *slgtk_version_string = SLGTK_VERSION_STRING;
-const char	    *slgtk_doc_dir        = SLGTK_DOC_DIR;
-
-
-int slgtk_debug;
+const int	slgtk_version	  = SLGTK_VERSION;
+const char	*slgtk_version_string = SLGTK_VERSION_STRING;
+int		slgtk_debug;
 
 SLang_CStruct_Field_Type *GtkAllocation_Layout = GdkRectangle_Layout;
 
@@ -262,16 +272,24 @@ static void sl_gtk_text_buffer_get_end_iter (Slirp_Opaque *textbuf)
    SLang_push_opaque(GtkTextIter_Type, iter, 1);
 }
 
+static void sl_gtk_text_buffer_get_iter_at_mark (Slirp_Opaque *textbuf,
+      		Slirp_Opaque *mark)
+{
+   GtkTextIter *iter;
+ 
+   if ( (iter = (GtkTextIter *)SLmalloc(sizeof(GtkTextIter))) != NULL)
+	gtk_text_buffer_get_iter_at_mark(textbuf->instance, iter,
+							mark->instance);
+
+   SLang_push_opaque(GtkTextIter_Type, iter, 1);
+}
+
 #if 0
 void        gtk_text_buffer_get_iter_at_line_index
                                             (GtkTextBuffer *buffer,
                                              GtkTextIter *iter,
                                              gint line_number,
                                              gint byte_index);
-void        gtk_text_buffer_get_iter_at_mark
-                                            (GtkTextBuffer *buffer,
-                                             GtkTextIter *iter,
-                                             GtkTextMark *mark);
 void        gtk_text_buffer_get_iter_at_child_anchor
                                             (GtkTextBuffer *buffer,
                                              GtkTextIter *iter,
@@ -1033,6 +1051,8 @@ static SLang_Intrin_Fun_Type GObject_Funcs[] =
 			sl_gtk_text_buffer_get_iter_at_line_offset,V,O,I,I),
   MAKE_INTRINSIC_2("gtk_text_buffer_get_iter_at_line",
 			sl_gtk_text_buffer_get_iter_at_line,V,O,I),
+  MAKE_INTRINSIC_2("gtk_text_buffer_get_iter_at_mark",
+			sl_gtk_text_buffer_get_iter_at_mark,V,O,O),
   MAKE_INTRINSIC_1("gtk_text_buffer_get_start_iter",
 		  	sl_gtk_text_buffer_get_start_iter,V,O),
   MAKE_INTRINSIC_1("gtk_text_buffer_get_end_iter",
@@ -1072,13 +1092,8 @@ static unsigned int _gtk_micro_version;
 
 static SLang_Intrin_Var_Type Global_Intrin_Vars[] =
 {
-   MAKE_VARIABLE("_slgtk_major_version",&slgtk_major_ver,UC,1),
-   MAKE_VARIABLE("_slgtk_minor_version",&slgtk_minor_ver,UC,1),
-   MAKE_VARIABLE("_slgtk_micro_version",&slgtk_micro_ver,UC,1),
-   MAKE_VARIABLE("_slgtk_version", &slgtk_version, I, 1),
-   MAKE_VARIABLE("_slgtk_doc_dir", &slgtk_doc_dir, S, 1),
-   MAKE_VARIABLE("_slgtk_version_string", &slgtk_version_string,S, 1),
-
+   MAKE_VARIABLE("_gtk_module_version", &slgtk_version, I, 1),
+   MAKE_VARIABLE("_gtk_module_version_string", &slgtk_version_string,S, 1),
    SLANG_END_INTRIN_VAR_TABLE
 };
 
@@ -1151,10 +1166,15 @@ static int init_sl_gtk(SLang_NameSpace_Type *ns)
 
    /* Unlike above, where we load the various intrinsics into the */
    /* given namespace, here we add them to the global namespace   */
-   if (SLang_is_defined("Global->_slgtk_version") == 0 &&
+   if (SLang_is_defined("Global->_gtk_module_version") == 0 &&
 	SLadd_intrin_var_table (Global_Intrin_Vars, NULL) == -1)
 	return -1;
 
+#ifdef SLGTK_STATIC_MODULE
+   if (SLdefine_for_ifdef ((char*)"GTK_MODULE_STATIC_BINARY") != 0)
+	return -1;
+#endif
+
    slgtk_debug = 0;
    return 0;
 }
